@@ -4,10 +4,9 @@
 #'  for a pre-defined set of tuning parameters that correspond to a model or
 #'  recipe across one or more resamples of the data.
 #'
-#' @param object A model workflow, R formula or recipe object.
-#' @param formula A traditional model formula.
-#' @param model A `parsnip` model specification (or `NULL` when `object` is a
-#' workflow).
+#' @param object A `parsnip` model specification or a [workflows::workflow()].
+#' @param preprocessor A traditional model formula or a recipe created using
+#'   [recipes::recipe()].
 #' @param resamples An `rset()` object.
 #' @param param_info A [dials::parameters()] object or `NULL`. If none is given,
 #' a parameters set is derived from other arguments. Passing this argument can
@@ -160,13 +159,14 @@
 #' library(recipes)
 #' library(rsample)
 #' library(parsnip)
+#' library(ggplot2)
 #'
-#' # ------------------------------------------------------------------------------
+#' # ---------------------------------------------------------------------------
 #'
 #' set.seed(6735)
 #' folds <- vfold_cv(mtcars, v = 5)
 #'
-#' # ------------------------------------------------------------------------------
+#' # ---------------------------------------------------------------------------
 #'
 #' # tuning recipe parameters:
 #'
@@ -185,13 +185,13 @@
 #' # Warnings will occur from making spline terms on the holdout data that are
 #' # extrapolations.
 #' spline_res <-
-#'   tune_grid(spline_rec, model = lin_mod, resamples = folds, grid = spline_grid)
+#'   tune_grid(lin_mod, spline_rec, resamples = folds, grid = spline_grid)
 #' spline_res
 #'
 #'
-#' show_best(spline_res, metric = "rmse", maximize = FALSE)
+#' show_best(spline_res, metric = "rmse")
 #'
-#' # ------------------------------------------------------------------------------
+#' # ---------------------------------------------------------------------------
 #'
 #' # tune model parameters only (example requires the `kernlab` package)
 #'
@@ -206,10 +206,10 @@
 #'
 #' # Use a space-filling design with 7 points
 #' set.seed(3254)
-#' svm_res <- tune_grid(car_rec, model = svm_mod, resamples = folds, grid = 7)
+#' svm_res <- tune_grid(svm_mod, car_rec, resamples = folds, grid = 7)
 #' svm_res
 #'
-#' show_best(svm_res, metric = "rmse", maximize = FALSE)
+#' show_best(svm_res, metric = "rmse")
 #'
 #' autoplot(svm_res, metric = "rmse") +
 #'   scale_x_log10()
@@ -220,51 +220,62 @@ tune_grid <- function(object, ...) {
 }
 
 #' @export
-#' @rdname tune_grid
 tune_grid.default <- function(object, ...) {
-  stop("The first argument should be either a formula, recipe, or workflow.",
-       call. = FALSE)
+  msg <- paste0(
+    "The first argument to [tune_grid()] should be either ",
+    "a model or workflow."
+  )
+  rlang::abort(msg)
 }
 
 #' @export
-#' @rdname tune_grid
 tune_grid.recipe <- function(object, model, resamples, ..., param_info = NULL,
                              grid = 10, metrics = NULL, control = control_grid()) {
-  if (is_missing(model) || !inherits(model, "model_spec")) {
-    stop("`model` should be a parsnip model specification object.", call. = FALSE)
-  }
 
+  lifecycle::deprecate_soft("0.1.0",
+                            what = "tune_grid.recipe()",
+                            details = deprecate_msg(match.call(), "tune_grid"))
   empty_ellipses(...)
 
-  wflow <-
-    workflow() %>%
-    add_recipe(object) %>%
-    add_model(model)
+  tune_grid(model, preprocessor = object, resamples = resamples,
+            param_info = param_info, grid = grid,
+            metrics = metrics, control = control)
+}
 
-  tune_grid_workflow(
-    wflow,
-    resamples = resamples,
-    grid = grid,
-    metrics = metrics,
-    pset = param_info,
-    control = control
-  )
+#' @export
+tune_grid.formula <- function(formula, model, resamples, ..., param_info = NULL,
+                              grid = 10, metrics = NULL, control = control_grid()) {
+
+  lifecycle::deprecate_soft("0.1.0",
+                            what = "tune_grid.formula()",
+                            details = deprecate_msg(match.call(), "tune_grid"))
+  empty_ellipses(...)
+
+  tune_grid(model, preprocessor = formula, resamples = resamples,
+            param_info = param_info, grid = grid,
+            metrics = metrics, control = control)
 }
 
 #' @export
 #' @rdname tune_grid
-tune_grid.formula <- function(formula, model, resamples, ..., param_info = NULL,
-                              grid = 10, metrics = NULL, control = control_grid()) {
-  if (is_missing(model) || !inherits(model, "model_spec")) {
-    stop("`model` should be a parsnip model specification object.", call. = FALSE)
+tune_grid.model_spec <- function(object, preprocessor, resamples, ...,
+                                 param_info = NULL, grid = 10, metrics = NULL,
+                                 control = control_grid()) {
+
+  if (rlang::is_missing(preprocessor) || !is_preprocessor(preprocessor)) {
+    rlang::abort(paste("To tune a model spec, you must preprocess",
+                       "with a formula or recipe"))
   }
 
   empty_ellipses(...)
 
-  wflow <-
-    workflow() %>%
-    add_formula(formula) %>%
-    add_model(model)
+  wflow <- add_model(workflow(), object)
+
+  if (is_recipe(preprocessor)) {
+    wflow <- add_recipe(wflow, preprocessor)
+  } else if (rlang::is_formula(preprocessor)) {
+    wflow <- add_formula(wflow, preprocessor)
+  }
 
   tune_grid_workflow(
     wflow,
@@ -315,7 +326,7 @@ tune_grid_workflow <-
     }
 
     class(resamples) <- unique(c("tune_results", class(resamples)))
-    resamples
+    save_attr(resamples, pset, metrics)
   }
 
 # ------------------------------------------------------------------------------
@@ -336,12 +347,19 @@ quarterback <- function(x) {
   )
 
   dplyr::case_when(
-     tune_rec & !tune_model ~ rlang::call2("tune_rec", !!!args),
-     tune_rec &  tune_model ~ rlang::call2("tune_rec_and_mod", !!!args),
-     has_form &  tune_model ~ rlang::call2("tune_mod_with_formula", !!!args),
+    tune_rec & !tune_model ~ rlang::call2("tune_rec", !!!args),
+    tune_rec &  tune_model ~ rlang::call2("tune_rec_and_mod", !!!args),
+    has_form &  tune_model ~ rlang::call2("tune_mod_with_formula", !!!args),
     !tune_rec &  tune_model ~ rlang::call2("tune_mod_with_recipe", !!!args),
-     has_form & !tune_model ~ rlang::call2("tune_nothing_with_formula", !!!args),
-     TRUE ~ rlang::call2("tune_nothing_with_recipe", !!!args)
+    has_form & !tune_model ~ rlang::call2("tune_nothing_with_formula", !!!args),
+    TRUE ~ rlang::call2("tune_nothing_with_recipe", !!!args)
   )
 }
 
+# ------------------------------------------------------------------------------
+
+save_attr <- function(x, param, metrics) {
+  attr(x, "parameters") <- param
+  attr(x, "metrics") <- metrics
+  x
+}
