@@ -24,7 +24,18 @@ from tune.concepts.flow import (
     TrialReport,
     TrialReportLogger,
 )
-from tune.concepts.space import Choice, Grid, Rand, RandInt, Space, StochasticExpression
+from tune.concepts.logger import MetricLogger
+from tune.concepts.space import (
+    Choice,
+    FuncParam,
+    Grid,
+    Rand,
+    RandInt,
+    Space,
+    StochasticExpression,
+    TransitionChoice,
+    TuningParametersTemplate,
+)
 from tune.iterative.objective import (
     IterativeObjectiveFunc,
     validate_iterative_objective,
